emdk->emsdp: Rename board

Real marketing name of the board was recently updated so
to accommodate that change renaming the board and all
related to it.

Signed-off-by: Alexey Brodkin <abrodkin@synopsys.com>
diff --git a/board/synopsys/emdk/MAINTAINERS b/board/synopsys/emdk/MAINTAINERS
deleted file mode 100644
index 605e338..0000000
--- a/board/synopsys/emdk/MAINTAINERS
+++ /dev/null
@@ -1,5 +0,0 @@
-EM DEVELOPMENT KIT BOARD
-M:	Alexey Brodkin <abrodkin@synopsys.com>
-S:	Maintained
-F:	board/synopsys/emdk/
-F:	configs/emdk_defconfig
diff --git a/board/synopsys/emdk/Kconfig b/board/synopsys/emsdp/Kconfig
similarity index 63%
rename from board/synopsys/emdk/Kconfig
rename to board/synopsys/emsdp/Kconfig
index a9b834d..8228bb5 100644
--- a/board/synopsys/emdk/Kconfig
+++ b/board/synopsys/emsdp/Kconfig
@@ -1,12 +1,12 @@
-if TARGET_EMDK
+if TARGET_EMSDP
 
 config SYS_BOARD
-	default "emdk"
+	default "emsdp"
 
 config SYS_VENDOR
 	default "synopsys"
 
 config SYS_CONFIG_NAME
-	default "emdk"
+	default "emsdp"
 
 endif
diff --git a/board/synopsys/emsdp/MAINTAINERS b/board/synopsys/emsdp/MAINTAINERS
new file mode 100644
index 0000000..6404013
--- /dev/null
+++ b/board/synopsys/emsdp/MAINTAINERS
@@ -0,0 +1,6 @@
+EM DEVELOPMENT KIT BOARD
+M:	Alexey Brodkin <abrodkin@synopsys.com>
+S:	Maintained
+F:	arch/arc/dts/emsdp.dts
+F:	board/synopsys/emsdp/
+F:	configs/emsdp_defconfig
diff --git a/board/synopsys/emdk/Makefile b/board/synopsys/emsdp/Makefile
similarity index 85%
rename from board/synopsys/emdk/Makefile
rename to board/synopsys/emsdp/Makefile
index 4926c4e..733a48c 100644
--- a/board/synopsys/emdk/Makefile
+++ b/board/synopsys/emsdp/Makefile
@@ -4,4 +4,4 @@
 # SPDX-License-Identifier:	GPL-2.0+
 #
 
-obj-y	+= emdk.o
+obj-y	+= emsdp.o
diff --git a/board/synopsys/emdk/README b/board/synopsys/emsdp/README
similarity index 90%
rename from board/synopsys/emdk/README
rename to board/synopsys/emsdp/README
index 706b547..034062e 100644
--- a/board/synopsys/emdk/README
+++ b/board/synopsys/emsdp/README
@@ -1,11 +1,12 @@
 ================================================================================
-Useful notes on bulding and using of U-Boot on ARC EM Development Kit (AKA EMDK)
+Useful notes on bulding and using of U-Boot on
+ARC EM Software Development Platform (AKA EMSDP)
 ================================================================================
 
    BOARD OVERVIEW
 
-   The DesignWare ARC EM Development Kit is FPGA-bases platform for rapid
-   software development on the ARC EM family of processors.
+   The DesignWare ARC EM Software Development Platform is FPGA-bases platform
+   for rapid software development on the ARC EM family of processors.
 
    Since this board is based on FPGA it's possible to load and use different
    versions of ARC EM CPUs. U-Boot is built to be run on the simplest
@@ -50,7 +51,7 @@
 
    1. Configure U-Boot:
       ------------------------->8----------------------
-      make emdk_defconfig
+      make emsdp_defconfig
       ------------------------->8----------------------
 
    2. To build Elf file (for example to be used with host debugger via JTAG
@@ -69,7 +70,7 @@
 
    EXECUTING U-BOOT
 
-   1. The EMDK board is supposed to auto-start U-Boot image stored in ROM on
+   1. The EMSDP board is supposed to auto-start U-Boot image stored in ROM on
       power-on. For that make sure VCCIO DIP-switches are all in "off" state.
 
    2. Though it is possible to load U-Boot as a simple Elf file via JTAG right
diff --git a/board/synopsys/emdk/emdk.c b/board/synopsys/emsdp/emsdp.c
similarity index 77%
rename from board/synopsys/emdk/emdk.c
rename to board/synopsys/emsdp/emsdp.c
index 79cafef..b5ec7f1 100644
--- a/board/synopsys/emdk/emdk.c
+++ b/board/synopsys/emsdp/emsdp.c
@@ -55,7 +55,7 @@
 		; /* loop forever till reset */
 }
 
-static int do_emdk_rom(cmd_tbl_t *cmdtp, int flag, int argc, char *const argv[])
+static int do_emsdp_rom(cmd_tbl_t *cmdtp, int flag, int argc, char *const argv[])
 {
 	u32 creg_boot = readl((u32 *)(CREG_BASE + CREG_BOOT_OFFSET));
 
@@ -71,17 +71,17 @@
 	return CMD_RET_SUCCESS;
 }
 
-cmd_tbl_t cmd_emdk[] = {
-	U_BOOT_CMD_MKENT(rom, 2, 0, do_emdk_rom, "", ""),
+cmd_tbl_t cmd_emsdp[] = {
+	U_BOOT_CMD_MKENT(rom, 2, 0, do_emsdp_rom, "", ""),
 };
 
-static int do_emdk(cmd_tbl_t *cmdtp, int flag, int argc, char *const argv[])
+static int do_emsdp(cmd_tbl_t *cmdtp, int flag, int argc, char *const argv[])
 {
 	cmd_tbl_t *c;
 
-	c = find_cmd_tbl(argv[1], cmd_emdk, ARRAY_SIZE(cmd_emdk));
+	c = find_cmd_tbl(argv[1], cmd_emsdp, ARRAY_SIZE(cmd_emsdp));
 
 	/* Strip off leading 'emdk' command */
 	argc--;
 	argv++;
 
@@ -92,8 +92,8 @@
 }
 
 U_BOOT_CMD(
-	emdk, CONFIG_SYS_MAXARGS, 0, do_emdk,
-	"Synopsys EMDK specific commands",
+	emsdp, CONFIG_SYS_MAXARGS, 0, do_emsdp,
+	"Synopsys EMSDP specific commands",
 	"rom unlock - Unlock non-volatile memory for writing\n"
-	"emdk rom lock - Lock non-volatile memory to prevent writing\n"
+	"emsdp rom lock - Lock non-volatile memory to prevent writing\n"
 );
@@ -71,17 +71,17 @@
 
-	/* Strip off leading 'emdk' command */
+	/* Strip off leading 'emsdp' command */
 	argc--;
 	argv++;